@@ -1,3 +1,3 @@
 from .base import Signer
 
-__all__ = ['Signer']
+__all__ = ["Signer"]
